@@ -344,11 +344,13 @@ resource {{department.tjp_id}} "{{department.name}}" {
 
         tjp_vacation_template='''vacation {{ vacation.start.strftime('%Y-%m-%d-%H:%M:%S') }} - {{ vacation.end.strftime('%Y-%m-%d-%H:%M:%S') }}''',
 
-        tjp_user_template='''resource {{user.tjp_id}} "{{user.name}}"{% if user.vacations %} {
-            {% for vacation in user.vacations -%}
-                {{vacation.to_tjp}}
-            {% endfor -%}
-        }{% endif %}''',
+        tjp_user_template='''resource {{user.tjp_id}} "{{user.name}}" {
+    efficiency {{user.efficiency}}
+{% if user.vacations %}
+{% for vacation in user.vacations %}
+    {{vacation.to_tjp}}
+{% endfor %}
+{% endif -%} }''',
 
         tjp_main_template="""# Generated By Stalker v{{stalker.__version__}}
         {{studio.to_tjp}}
